==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/viking2/dialogs_nl.lua <==

dialogId("dr1-m-dlouho", "font_small", "This ship must have sunk long time ago.")
dialogStr("Dit schip moet al een hele tijd geleden gezonken zijn.")


dialogId("dr1-v-urcite", "font_big", "Definitely. It`s one of the earliest drakkars. Judging by the shape of the head, number of spirals and color of the water I think it belonged to the grandfather of Eric the Red.")
dialogStr("Inderdaad. Het is een van de vroegste drakkars. De vorm van het hoofd, het aantal spiralen, en de kleur van het water doen vermoeden dat het van de grootvader van Eric de Rode was.")


dialogId("dr1-v-olaf", "font_big", "Or to the father-in-law of Olaf the Brave.")
dialogStr("Of de schoonvader van Olaf de Stoute.")


dialogId("dr1-v-leif", "font_big", "Or maybe to the great-uncle of Leif the Skillful.")
dialogStr("Of misschien de oudoom van Leif de Handige.")


dialogId("dr1-v-harold", "font_big", "It could also belong to the niece of Harold the Great.")
dialogStr("Het zou ook van de nicht van Harold de Grote kunnen zijn.")


dialogId("dr1-v-snorr", "font_big", "Or possibly to the aunt of Snorr the Courageous.")
dialogStr("Of misschien van de tante van Snorr de Moedige.")


dialogId("dr1-v-thorson", "font_big", "It is even possible it belonged to Thorson the Hard.")
dialogStr("Het zou zelfs kunnen dat het eigendom was van Thorsen de Harde.")


dialogId("dr1-x-erik", "font_lightgrey", "I always thought I was the fishing boat of Eric the Unready... But today I learned the truth. Yes, it`s never too late to start a new life!")
dialogStr("Ik dacht altijd dat ik de visserschuit van Eric de Onvoorbereidde was.... Maar vandaag weet ik eindelijk de waarheid. Ja, het is nooit te laat om met een nieuw leven te beginnen!")


dialogId("dr-m-podivej", "font_small", "Look at that poor dog.")
dialogStr("Moet je die arme hond zien.")


dialogId("dr-m-nedycha", "font_small", "Doesn't he seem to be breathing kind of strangely?")
dialogStr("Ademt hij niet een beetje raar?")


dialogId("dr-v-napsa", "font_big", "For a dog under water I think he's doing rather well.")
dialogStr("Voor een hond onder water doet hij het anders best aardig.")


dialogId("dr-v-nato", "font_big", "He doesn't look all that bad considering that he's been here for a few centuries.")
dialogStr("Hij ziet er heel niet slecht uit als je bedenkt dat hij hier al een paar eeuwen is.")


dialogId("dr-8-ztichni1", "font_viking8", "Shut up!")
dialogStr("Hou je bek!")


dialogId("dr-8-ztichni2", "font_viking8", "Will you shut up already!")
dialogStr("Hou nou eindelijk je mond!")


dialogId("dr-8-nenechas", "font_viking8", "So, you`re not going to shut up, are you?")
dialogStr("Zo, jij wil je smoelwerk niet dicht houden?")


dialogId("dr-8-aaa", "font_viking8", "Aaaaargh...")
dialogStr("Aaaaargh...")


dialogId("dr-6-checheche", "font_viking6", "He-he-he-he-he... Eh-eh-eh-eh...")
dialogStr("He-he-he-he-he... Eh-eh-eh-eh...")


dialogId("dr-5-srab1", "font_viking5", "Is it over?")
dialogStr("Is het afgelopen?")


dialogId("dr-5-srab2", "font_viking5", "Are we safe now?")
dialogStr("Zijn we nu veilig?")


dialogId("dr-5-srab3", "font_viking5", "Is the fight over?")
dialogStr("Is het gevecht afgelopen?")


dialogId("dr-5-srab4", "font_viking5", "Is the enemy finally gone?")
dialogStr("Is de vijand eindelijk weg?")


dialogId("dr-5-srab5", "font_viking5", "Are we still fighting?")
dialogStr("Vechten we nogsteeds?")


dialogId("dr-2-uzbudeme1", "font_viking2", "Are we in Valhalla yet, chief?")
dialogStr("Baas, zijn we nou al in Valhalla?")


dialogId("dr-2-uzbudeme2", "font_viking2", "When are we going to get to Valhalla?")
dialogStr("Hoe ver is het nog naar Valhalla?")


dialogId("dr-1-aztambudem", "font_viking1", "I`ll let you know once we get there.")
dialogStr("Je hoort het wel als we er zijn.")


dialogId("dr-2-odskocit", "font_viking2", "Can I go relieve myself, sir?")
dialogStr("Baas, ik moet even naar het kleine kamertje.")


dialogId("dr-1-pockej", "font_viking1", "Wait till we get to Valhalla.")
dialogStr("Hou het maar op tot we in Valhalla zijn.")


dialogId("dr-2-netrva", "font_viking2", "Isn`t this journey to Valhalla taking a bit too long?")
dialogStr("Duurt deze reis naar Valhalla niet een beetje lang?")


dialogId("dr-1-trpelivost", "font_viking1", "Patience is the sign of a true warrior.")
dialogStr("Een echte krijger heeft geduld.")


dialogId("dr-2-urcite", "font_viking2", "Are you sure this is how to get to Valhalla?")
dialogStr("Weet je zeker dat we zo bij Valhalla komen?")


dialogId("dr-1-bojovnik", "font_viking1", "A warrior has to trust his commander!")
dialogStr("Ein krijger moet zijn aanvoerder vertrouwen!")


dialogId("dr-1-achjo", "font_viking1", "Ahhh, I`m in charge of a ship full of cowards.")
dialogStr("Ahhh, ik heb de leiding over een schip vol laffaards!")


dialogId("dr-1-procja", "font_viking1", "Why did I have to get a ship full of laughing buffoons?")
dialogStr("Waarom krijg ik weer het schip vol grinnikende malloten?")


dialogId("dr-1-chechtajici", "font_viking1", "Laughing buffoons, a slobbering dog. I think I`ll go drown myself.")
dialogStr("Grinnekende malloten, een kwijlend hondje. Ik denk dat ik mezelf maar ga verdrinken.")


dialogId("dr-3-spravny", "font_viking3", "Real Vikings have beards.")
dialogStr("Echte Vikingen hebben baarden.")


dialogId("dr-4-copy", "font_viking4", "B-b-braids are in n-nowadays.")
dialogStr("T-t-tegenwoordig zijn v-vlechten weer in.")


dialogId("dr-3-cojeto", "font_viking3", "What kind of fad is that? Braids? For crying out loud.")
dialogStr("Wat is dat voor onzin? Vlechten? Laat me niet lachen!")


dialogId("dr-4-magazin", "font_viking4", "V-v-viking Fashion M-m-monthly r-recommends a blonde braid to complement a d-d-dark helmet and b-blue shield.")
dialogStr("V-v-volgens V-v-viking Mode k-k-kun staat een B-blonde V-vlecht het beste bij een d-d-donkere helm en een blauw s-s-schield.")


dialogId("dr-3-stakovou", "font_viking3", "I simply don`t agree with such a fad.")
dialogStr("Ik doe niet aan modegrillen.")


dialogId("dr-3-radeji", "font_viking3", "You should stick to the Viking traditions instead.")
dialogStr("Je kunt het beter bij de echt Viking tradities houden.")


dialogId("dr-4-moderni", "font_viking4", "B-b-but I`m c-c-cool!")
dialogStr("M-m-maar ik ben c-c-cool!")


dialogId("dr-4-erik", "font_viking4", "Even Erik the G-g-great Eric had a b-b-braid!")
dialogStr("Z-z-zelfs Erik de G-g-grote Erik had een v-vlecht!")


dialogId("dr-3-nesmysl", "font_viking3", "Nonsense. He had a beard.")
dialogStr("Onzin. Hij had een baard.")


dialogId("dr-4-taky", "font_viking4", "But h-he also h-had a b-b-braid.")
dialogStr("M-m-maar hij ha-ha-had ook een v-v-vlecht.")


dialogId("dr-3-nemel", "font_viking3", "He did not. And that`s final.")
dialogStr("Nee, die had hij niet, en daarmee uit!")


dialogId("dr-4-myslis", "font_viking4", "D-d-do you think that a b-b-beard would suit me b-b-better?")
dialogStr("D-d-denk je dat een b-b-baard me b-b-beter zou staan?")


dialogId("dr-3-samozrejme", "font_viking3", "Definitely.")
dialogStr("Ja, zeker weten.")


dialogId("dr-4-budu", "font_viking4", "I`ll th-th-think it o-over.")
dialogStr("D-d-daar moet ik maar eens over nadenken, d-d-dan.")


dialogId("dr-4-hmmm", "font_viking4", "Hmmm... Ehmmm... Hahmmm...")
dialogStr("Hmmm... Ehmmm... Hahmmm...")


dialogId("dr-4-ne", "font_viking4", "N-no, b-b-braids are d-definitely b-b-better.")
dialogStr("N-n-nee, v-v-vlechten zijn absoluut b-b-beter.")


dialogId("dr-3-mladez", "font_viking3", "Today`s youth - absolutely unbelievable.")
dialogStr("De jeugd van tegenwoordig - ongeloofelijk.")


dialogId("dr-3-chlap", "font_viking3", "A warrior with braids. It`s unheard of.")
dialogStr("Een krijger met vlechten. Dat geloof je toch niet.")


dialogId("dr-3-mladi", "font_viking3", "You youngsters just think you can get away with anything today.")
dialogStr("Jullie jongelingen denken dat jullie alles kunnen maken.")


dialogId("dr-4-stejne", "font_viking4", "Well, I still look cool.")
dialogStr("Nou ja, ik zie er nogsteeds cool uit.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/viking2/dialogs_nl.lua <==

dialogId("dr1-m-dlouho", "font_small", "This ship must have sunk long time ago.")
dialogStr("Dit schip moet al een hele tijd geleden gezonken zijn.")


dialogId("dr1-v-urcite", "font_big", "Definitely. It’s one of the earliest drakkars. Judging by the shape of the head, number of spirals and color of the water I think it belonged to the grandfather of Eric the Red.")
dialogStr("Inderdaad. Het is een van de vroegste drakhars. De vorm van het hoofd, het aantal spiralen, en de kleur van het water doen vermoeden dat het van de grootvader van Erik de Rode was.")


dialogId("dr1-v-olaf", "font_big", "Or to the father-in-law of Olaf the Brave.")
dialogStr("Of de schoonvader van Olaf de Stoute.")


dialogId("dr1-v-leif", "font_big", "Or maybe to the great-uncle of Leif the Skillful.")
dialogStr("Of misschien de oudoom van Leif de Handige.")


dialogId("dr1-v-harold", "font_big", "It could also belong to the niece of Harold the Great.")
dialogStr("Het zou ook van de nicht van Harold de Grote kunnen zijn.")


dialogId("dr1-v-snorr", "font_big", "Or possibly to the aunt of Snorr the Courageous.")
dialogStr("Of misschien van de tante van Snorr de Moedige.")


dialogId("dr1-v-thorson", "font_big", "It is even possible it belonged to Thorson the Hard.")
dialogStr("Het zou zelfs kunnen dat het eigendom was van Thorsen de Harde.")


dialogId("dr1-x-erik", "font_lightgrey", "I always thought I was the fishing boat of Eric the Unready... But today I learned the truth. Yes, it’s never too late to start a new life!")
dialogStr("Ik dacht altijd dat ik de vissersschuit van Erik de Onvoorbereide was.... Maar vandaag weet ik eindelijk de waarheid. Ja, het is nooit te laat om met een nieuw leven te beginnen!")


dialogId("dr-m-podivej", "font_small", "Look at that poor dog.")
dialogStr("Moet je die arme hond zien.")


dialogId("dr-m-nedycha", "font_small", "Doesn't he seem to be breathing kind of strangely?")
dialogStr("Ademt hij niet een beetje raar?")


dialogId("dr-v-napsa", "font_big", "For a dog under water I think he's doing rather well.")
dialogStr("Voor een hond onderwater doet hij het anders best aardig.")


dialogId("dr-v-nato", "font_big", "He doesn't look all that bad considering that he's been here for a few centuries.")
dialogStr("Hij ziet er heel niet slecht uit als je bedenkt dat hij hier al een paar eeuwen is.")


dialogId("dr-8-ztichni1", "font_viking8", "Shut up!")
dialogStr("Hou je bek!")


dialogId("dr-8-ztichni2", "font_viking8", "Will you shut up already!")
dialogStr("Hou nou eindelijk je mond!")


dialogId("dr-8-nenechas", "font_viking8", "So, you’re not going to shut up, are you?")
dialogStr("Zo, jij wil je smoelwerk niet dicht houden?")


dialogId("dr-8-aaa", "font_viking8", "Aaaaargh...")
dialogStr("Aaaaargh...")


dialogId("dr-6-checheche", "font_viking6", "He-he-he-he-he... Eh-eh-eh-eh...")
dialogStr("He-he-he-he-he... Eh-eh-eh-eh...")


dialogId("dr-5-srab1", "font_viking5", "Is it over?")
dialogStr("Is het afgelopen?")


dialogId("dr-5-srab2", "font_viking5", "Are we safe now?")
dialogStr("Zijn we nu veilig?")


dialogId("dr-5-srab3", "font_viking5", "Is the fight over?")
dialogStr("Is het gevecht afgelopen?")


dialogId("dr-5-srab4", "font_viking5", "Is the enemy finally gone?")
dialogStr("Is de vijand eindelijk weg?")


dialogId("dr-5-srab5", "font_viking5", "Are we still fighting?")
dialogStr("Zijn we nogsteeds aan het vechten?")


dialogId("dr-2-uzbudeme1", "font_viking2", "Are we in Valhalla yet, chief?")
dialogStr("Baas, zijn we nou al in Valhalla?")


dialogId("dr-2-uzbudeme2", "font_viking2", "When are we going to get to Valhalla?")
dialogStr("Hoe ver is het nog naar Valhalla?")


dialogId("dr-1-aztambudem", "font_viking1", "I’ll let you know once we get there.")
dialogStr("Je hoort het wel als we er zijn.")


dialogId("dr-2-odskocit", "font_viking2", "Can I go relieve myself, sir?")
dialogStr("Baas, ik moet naar de wc.")


dialogId("dr-1-pockej", "font_viking1", "Wait till we get to Valhalla.")
dialogStr("Hou het maar op tot we in Valhalla zijn.")


dialogId("dr-2-netrva", "font_viking2", "Isn’t this journey to Valhalla taking a bit too long?")
dialogStr("Duurt deze reis naar Valhalla niet een beetje lang?")


dialogId("dr-1-trpelivost", "font_viking1", "Patience is the sign of a true warrior.")
dialogStr("Een echte krijger heeft geduld.")


dialogId("dr-2-urcite", "font_viking2", "Are you sure this is how to get to Valhalla?")
dialogStr("Weet je zeker dat we zo bij Valhalla komen?")


dialogId("dr-1-bojovnik", "font_viking1", "A warrior has to trust his commander!")
dialogStr("Een krijger moet zijn aanvoerder vertrouwen!")


dialogId("dr-1-achjo", "font_viking1", "Ahhh, I’m in charge of a ship full of cowards.")
dialogStr("Ahhh, ik heb de leiding over een schip vol laffaards!")


dialogId("dr-1-procja", "font_viking1", "Why did I have to get a ship full of laughing buffoons?")
dialogStr("Waarom krijg ik weer een schip vol grinnikende malloten?")


dialogId("dr-1-chechtajici", "font_viking1", "Laughing buffoons, a slobbering dog. I think I’ll go drown myself.")
dialogStr("Grinnekende malloten, een kwijlend hondje. Ik denk dat ik mezelf maar ga verdrinken.")


dialogId("dr-3-spravny", "font_viking3", "Real Vikings have beards.")
dialogStr("Echte vikingen hebben baarden.")


dialogId("dr-4-copy", "font_viking4", "B-b-braids are in n-nowadays.")
dialogStr("T-t-tegenwoordig zijn v-vlechten weer in.")


dialogId("dr-3-cojeto", "font_viking3", "What kind of fad is that? Braids? For crying out loud.")
dialogStr("Wat is dat voor onzin? Vlechten? Laat me niet lachen!")


dialogId("dr-4-magazin", "font_viking4", "V-v-viking Fashion M-m-monthly r-recommends a blonde braid to complement a d-d-dark helmet and b-blue shield.")
dialogStr("V-v-volgens V-v-viking Mode staat een B-blonde V-vlecht het beste bij een d-d-donkere helm en een blauw s-s-schield.")


dialogId("dr-3-stakovou", "font_viking3", "I simply don’t agree with such a fad.")
dialogStr("Ik doe niet aan modegrillen.")


dialogId("dr-3-radeji", "font_viking3", "You should stick to the Viking traditions instead.")
dialogStr("Je kunt je beter aan de echt vikingtradities houden.")


dialogId("dr-4-moderni", "font_viking4", "B-b-but I’m c-c-cool!")
dialogStr("M-m-maar ik ben c-c-cool!")


dialogId("dr-4-erik", "font_viking4", "Even Erik the G-g-great Eric had a b-b-braid!")
dialogStr("Z-z-zelfs Erik de G-g-grote Erik had een v-vlecht!")


dialogId("dr-3-nesmysl", "font_viking3", "Nonsense. He had a beard.")
dialogStr("Onzin. Hij had een baard.")


dialogId("dr-4-taky", "font_viking4", "But h-he also h-had a b-b-braid.")
dialogStr("M-m-maar hij ha-ha-had ook een v-v-vlecht.")


dialogId("dr-3-nemel", "font_viking3", "He did not. And that’s final.")
dialogStr("Nee, die had hij niet, en daarmee uit!")


dialogId("dr-4-myslis", "font_viking4", "D-d-do you think that a b-b-beard would suit me b-b-better?")
dialogStr("D-d-denk je dat een b-b-baard me b-b-beter zou staan?")


dialogId("dr-3-samozrejme", "font_viking3", "Definitely.")
dialogStr("Ja, zeker weten.")


dialogId("dr-4-budu", "font_viking4", "I’ll th-th-think it o-over.")
dialogStr("D-d-daar moet ik maar eens over nadenken, d-d-dan.")


dialogId("dr-4-hmmm", "font_viking4", "Hmmm... Ehmmm... Hahmmm...")
dialogStr("Hmmm... Ehmmm... Hahmmm...")


dialogId("dr-4-ne", "font_viking4", "N-no, b-b-braids are d-definitely b-b-better.")
dialogStr("N-n-nee, v-v-vlechten zijn absoluut b-b-beter.")


dialogId("dr-3-mladez", "font_viking3", "Today’s youth - absolutely unbelievable.")
dialogStr("De jeugd van tegenwoordig - ongeloofelijk.")


dialogId("dr-3-chlap", "font_viking3", "A warrior with braids. It’s unheard of.")
dialogStr("Een krijger met vlechten. Dat geloof je toch niet.")


dialogId("dr-3-mladi", "font_viking3", "You youngsters just think you can get away with anything today.")
dialogStr("Jullie jongkies denken dat jullie alles kunnen maken.")


dialogId("dr-4-stejne", "font_viking4", "Well, I still look cool.")
dialogStr("Nou ja, ik zie er nogsteeds cool uit.")
